@@ -29,21 +29,19 @@
 #include "akonadicalendar_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KSystemTimeZones>
+#include <QTimeZone>
 
 using namespace KCalCore;
 using namespace Akonadi;
 
 struct Akonadi::Scheduler::Private {
 public:
-    Private(Scheduler *qq) : mFreeBusyCache(nullptr)
-        , mShowDialogs(true)
-        , q(qq)
+    Private(Scheduler *qq) : q(qq)
     {
     }
 
-    FreeBusyCache *mFreeBusyCache;
-    bool mShowDialogs;
+    FreeBusyCache *mFreeBusyCache = nullptr;
+    bool mShowDialogs = true;
     Scheduler *const q;
 };
 
@@ -51,7 +49,7 @@ Scheduler::Scheduler(QObject *parent) : QObject(parent)
     , d(new Akonadi::Scheduler::Private(this))
 {
     mFormat = new ICalFormat();
-    mFormat->setTimeSpec(KSystemTimeZones::local());
+    mFormat->setTimeZone(QTimeZone::systemTimeZone());
 }
 
 Scheduler::~Scheduler()
@@ -350,7 +348,7 @@ void Scheduler::acceptCancel(const IncidenceBase::Ptr &incidenceBase,
 
     const Incidence::List existingIncidences = calendar->incidencesFromSchedulingID(incidence->uid());
     qCDebug(AKONADICALENDAR_LOG) << "Scheduler::acceptCancel="
-                                 << KCalUtils::Stringify::scheduleMessageStatus(status)   //krazy2:exclude=kdebug
+                                 << KCalUtils::Stringify::scheduleMessageStatus(status)
                                  << ": found " << existingIncidences.count()
                                  << " incidences with schedulingID " << incidence->schedulingID();
 
@@ -508,7 +506,7 @@ void Scheduler::acceptReply(const IncidenceBase::Ptr &incidenceBase,
                       attNew->fullName(), incidence->summary());
             if (!attNew->delegator().isEmpty()) {
                 msg = i18nc("@info", "%1 wants to attend %2 on behalf of %3.",
-                            attNew->fullName(), incidence->summary() , attNew->delegator());
+                            attNew->fullName(), incidence->summary(), attNew->delegator());
             }
             if (KMessageBox::questionYesNo(
                         nullptr, msg, i18nc("@title", "Uninvited attendee"),
